pub fn schema_write() -> RwLockWriteGuard<'static, Schema>Expand description
Acquire a write guard to the global schema during build-time codegen.
Panics
Panics if the process-global schema lock has been poisoned.
pub fn schema_write() -> RwLockWriteGuard<'static, Schema>Acquire a write guard to the global schema during build-time codegen.
Panics if the process-global schema lock has been poisoned.