NamedTypeFragment

Enum NamedTypeFragment 

pub enum NamedTypeFragment {
    Record(RecordTypeFragment),
    Enum(EnumTypeFragment),
    Newtype {
        source_key: TypeSourceKey,
        name: SchemaName,
        inner: FieldType,
    },
    List {
        source_key: TypeSourceKey,
        name: SchemaName,
        item: FieldType,
    },
    Set {
        source_key: TypeSourceKey,
        name: SchemaName,
        item: FieldType,
    },
    Map {
        source_key: TypeSourceKey,
        name: SchemaName,
        key: FieldType,
        value: FieldType,
    },
    Tuple {
        source_key: TypeSourceKey,
        name: SchemaName,
        members: Vec<TupleElementFragment>,
    },
}
Named reusable type definition.

Variants



Record(RecordTypeFragment)

Record type.



Enum(EnumTypeFragment)

Enum type.



Newtype

Transparent named wrapper.

Fields

source_key: TypeSourceKey

Typed proposal key derived from the current name.

name: SchemaName

Current schema name.

inner: FieldType

Wrapped logical type.



List

Homogeneous ordered collection.

Fields

source_key: TypeSourceKey

Typed proposal key derived from the current name.

name: SchemaName

Current schema name.

item: FieldType

Element type.



Set

Homogeneous unique collection.

Fields

source_key: TypeSourceKey

Typed proposal key derived from the current name.

name: SchemaName

Current schema name.

item: FieldType

Element type.



Map

Homogeneous key/value collection.

Fields

source_key: TypeSourceKey

Typed proposal key derived from the current name.

name: SchemaName

Current schema name.

key: FieldType

Key type.

value: FieldType

Value type.



Tuple

Ordered heterogeneous product.

Fields

source_key: TypeSourceKey

Typed proposal key derived from the current name.

name: SchemaName

Current schema name.

members: Vec<TupleElementFragment>

Ordered member types.

Implementations

Source

impl NamedTypeFragment

pub fn newtype(name: SchemaName, inner: FieldType) -> Self

Construct one transparent named wrapper from its current name.

pub fn list(name: SchemaName, item: FieldType) -> Self

Construct one named ordered collection from its current name.

pub fn set(name: SchemaName, item: FieldType) -> Self

Construct one named unique collection from its current name.

pub fn map(name: SchemaName, key: FieldType, value: FieldType) -> Self

Construct one named key/value collection from its current name.

pub fn tuple(name: SchemaName, members: Vec<TupleElementFragment>) -> Self

Construct one named heterogeneous product from its current name.

pub const fn source_key(&self) -> &TypeSourceKey

Borrow the typed proposal key derived from the current type name.

pub const fn name(&self) -> &SchemaName

Borrow the current type name.