Item

Struct Item 

pub struct Item { /* private fields */ }
Item

Canonical schema item descriptor for one scalar, relation, or primitive field target plus its attached sanitizers and validators.

Implementations

Source

impl Item

pub const fn new( target: ItemTarget, relation: Option<&'static str>, scale: Option<u32>, validators: &'static [TypeValidator], sanitizers: &'static [TypeSanitizer], indirect: bool, ) -> Self

pub const fn target(&self) -> &ItemTarget

pub const fn relation(&self) -> Option<&'static str>

pub const fn scale(&self) -> Option<u32>

pub const fn validators(&self) -> &'static [TypeValidator]

pub const fn sanitizers(&self) -> &'static [TypeSanitizer]

pub const fn indirect(&self) -> bool

pub const fn is_relation(&self) -> bool