StableMemoryAllocationMetadata

Struct StableMemoryAllocationMetadata 

pub struct StableMemoryAllocationMetadata { /* private fields */ }
Diagnostic schema metadata associated with a stable-memory allocation.

This metadata does not participate in durable allocation identity. The durable identity remains memory_id + stable_key.

Implementations

Source

impl StableMemoryAllocationMetadata

pub const fn from_accepted_schema_contract( schema_version: u32, schema_fingerprint: String, ) -> Self

Build allocation metadata from an accepted schema/catalog authority.

pub const fn absent() -> Self

Build absent allocation metadata for allocations with no accepted schema/catalog authority.

pub const fn schema_version(&self) -> Option<u32>

Accepted schema/catalog version, when known.

pub const fn schema_fingerprint(&self) -> Option<&str>

Accepted schema/catalog fingerprint, when known.