StoreJournaledMemoryConfig

Struct StoreJournaledMemoryConfig 

pub struct StoreJournaledMemoryConfig { /* private fields */ }
Stable-memory IDs for the four durable roles owned by one journaled cached-stable store.

Implementations

Source

impl StoreJournaledMemoryConfig

pub const fn new( data_memory_id: u8, index_memory_id: u8, schema_memory_id: u8, journal_memory_id: u8, ) -> Self

Build a journaled memory configuration from canonical data, index, schema, and journal-tail memory IDs.

pub const fn data_memory_id(self) -> u8

Canonical data-store stable memory ID.

pub const fn index_memory_id(self) -> u8

Canonical index-store stable memory ID.

pub const fn schema_memory_id(self) -> u8

Canonical schema-store stable memory ID.

pub const fn journal_memory_id(self) -> u8

Durable journal-tail stable memory ID.