pub struct StoreStableMemoryConfig { /* private fields */ }Expand description
Stable-memory IDs for the three durable roles owned by one store.
Implementations
Sourceimpl StoreStableMemoryConfig
impl StoreStableMemoryConfig
Sourcepub const fn new(
data_memory_id: u8,
index_memory_id: u8,
schema_memory_id: u8,
) -> Self
pub const fn new( data_memory_id: u8, index_memory_id: u8, schema_memory_id: u8, ) -> Self
Build a stable-memory configuration from data, index, and schema memory IDs.
Sourcepub const fn data_memory_id(self) -> u8
pub const fn data_memory_id(self) -> u8
Data-store stable memory ID.
Sourcepub const fn index_memory_id(self) -> u8
pub const fn index_memory_id(self) -> u8
Index-store stable memory ID.
Sourcepub const fn schema_memory_id(self) -> u8
pub const fn schema_memory_id(self) -> u8
Schema-store stable memory ID.