pub struct Value { /* private fields */ }Expand description
Value
Canonical value descriptor pairing cardinality with one item definition.
Implementations
Sourceimpl Value
impl Value
Sourcepub const fn new(cardinality: Cardinality, item: Item) -> Self
pub const fn new(cardinality: Cardinality, item: Item) -> Self
Build one value descriptor from its schema cardinality and item target.
pub const fn cardinality(&self) -> Cardinality
pub const fn item(&self) -> &Item