pub trait ValidateNode {
// Provided method
fn validate(&self) -> Result<(), ErrorTree> { ... }
}Expand description
ValidateNode
Trait implemented by schema nodes that validate local invariants against the surrounding schema graph.
pub trait ValidateNode {
// Provided method
fn validate(&self) -> Result<(), ErrorTree> { ... }
}ValidateNode
Trait implemented by schema nodes that validate local invariants against the surrounding schema graph.