pub struct Date(/* private fields */);Implementations
Sourceimpl Date
impl Date
Sourcepub fn try_new(y: i32, m: u8, d: u8) -> Option<Self>
pub fn try_new(y: i32, m: u8, d: u8) -> Option<Self>
Build a date from exact calendar parts.
Returns None when any component is out of range.
Sourcepub const fn try_from_days_since_epoch(days: i32) -> Option<Self>
pub const fn try_from_days_since_epoch(days: i32) -> Option<Self>
Construct from the bounded internal day-count representation.
Sourcepub const fn as_days_since_epoch(self) -> i32
pub const fn as_days_since_epoch(self) -> i32
Return the internal day-count representation.
Sourcepub fn try_from_i64(days: i64) -> Option<Self>
pub fn try_from_i64(days: i64) -> Option<Self>
Fallible conversion from i64 day-count representation.
Sourcepub fn try_from_u64(days: u64) -> Option<Self>
pub fn try_from_u64(days: u64) -> Option<Self>
Fallible conversion from u64 day-count representation.
Sourcepub fn checked_add_days(self, days: i64) -> Option<Self>
pub fn checked_add_days(self, days: i64) -> Option<Self>
Add a signed number of days without leaving the supported calendar.
Sourcepub fn checked_sub_days(self, days: i64) -> Option<Self>
pub fn checked_sub_days(self, days: i64) -> Option<Self>
Subtract a signed number of days without leaving the supported calendar.
Sourcepub fn days_since(self, earlier: Self) -> i64
pub fn days_since(self, earlier: Self) -> i64
Return the signed number of days from earlier to this date.