pub struct FieldFragment { /* private fields */ }Expand description
One field definition keyed by its current source name.
Implementations
Sourceimpl FieldFragment
impl FieldFragment
Sourcepub fn new(
name: SchemaName,
field_type: FieldType,
nullable: bool,
insert_policy: FieldInsertPolicy,
management: Option<FieldManagementPolicy>,
) -> Self
pub fn new( name: SchemaName, field_type: FieldType, nullable: bool, insert_policy: FieldInsertPolicy, management: Option<FieldManagementPolicy>, ) -> Self
Construct one field definition.
Sourcepub const fn source_key(&self) -> &FieldSourceKey
pub const fn source_key(&self) -> &FieldSourceKey
Borrow the typed proposal key derived from the current field name.
Sourcepub const fn name(&self) -> &SchemaName
pub const fn name(&self) -> &SchemaName
Borrow the current field name.
Sourcepub const fn field_type(&self) -> &FieldType
pub const fn field_type(&self) -> &FieldType
Borrow the logical field type.
Sourcepub const fn insert_policy(&self) -> &FieldInsertPolicy
pub const fn insert_policy(&self) -> &FieldInsertPolicy
Borrow the future-write insert policy.
Sourcepub const fn management(&self) -> Option<FieldManagementPolicy>
pub const fn management(&self) -> Option<FieldManagementPolicy>
Return the optional accepted management policy.