pub struct Principal(/* private fields */);Expand description
Canonical principal atom.
Implementations
Sourceimpl Principal
impl Principal
Sourcepub const MAX_LENGTH_IN_BYTES: u32 = 29
pub const MAX_LENGTH_IN_BYTES: u32 = 29
Maximum canonical principal byte length.
Sourcepub fn from_text(text: &str) -> Result<Self, PrincipalError>
pub fn from_text(text: &str) -> Result<Self, PrincipalError>
Parse canonical textual principal form.
Errors
Returns PrincipalError::InvalidText for invalid text.
Sourcepub const fn from_slice(bytes: &[u8]) -> Self
pub const fn from_slice(bytes: &[u8]) -> Self
Construct from canonical principal bytes.
Panics
Panics when bytes exceeds the canonical 29-byte principal limit.
Use Principal::try_from_bytes for untrusted input.
Sourcepub const fn stored_bytes(&self) -> Result<&[u8], PrincipalEncodeError>
pub const fn stored_bytes(&self) -> Result<&[u8], PrincipalEncodeError>
Borrow bounded canonical bytes.
Errors
Returns a typed error if an upstream value violates the canonical principal length.
Sourcepub const fn try_from_bytes(bytes: &[u8]) -> Result<Self, PrincipalDecodeError>
pub const fn try_from_bytes(bytes: &[u8]) -> Result<Self, PrincipalDecodeError>
Decode bounded canonical bytes.
Errors
Returns a typed error when bytes exceeds the principal bound.