pub struct RecordTypeFragment { /* private fields */ }Expand description
Named record-type definition.
Implementations
Sourceimpl RecordTypeFragment
impl RecordTypeFragment
Sourcepub fn try_new(
name: SchemaName,
fields: Vec<RecordFieldFragment>,
) -> Result<Self, SchemaContractError>
pub fn try_new( name: SchemaName, fields: Vec<RecordFieldFragment>, ) -> Result<Self, SchemaContractError>
Construct and canonicalize a record definition.
Errors
Returns a typed contract error for overflow, duplicates, or malformed fields.
Sourcepub const fn source_key(&self) -> &TypeSourceKey
pub const fn source_key(&self) -> &TypeSourceKey
Borrow the typed proposal key derived from the current record name.
Sourcepub const fn name(&self) -> &SchemaName
pub const fn name(&self) -> &SchemaName
Borrow the current record name.
Sourcepub fn fields(&self) -> &[RecordFieldFragment]
pub fn fields(&self) -> &[RecordFieldFragment]
Borrow canonical record fields.