pub fn schema_write() -> RwLockWriteGuard<'static, Schema>Expand description
Acquire a write guard to the global schema during build-time codegen.
pub fn schema_write() -> RwLockWriteGuard<'static, Schema>Acquire a write guard to the global schema during build-time codegen.