Module node

Module node 

Schema node graph for validated canister/entity/type definitions.

This module owns the typed node descriptors used by schema validation, derive code generation, and visitor traversal.

Structs

Args
Args
Canister
Canister
Def
Entity
Entity
Enum
Enum
EnumVariant
EnumVariant
Field
FieldList
FieldList
Index
Index
Item
Item
List
List
Map
Map
Newtype
Newtype
PrimaryKey
PrimaryKey
Record
Record
RelationEdge
RelationEdge
Sanitizer
Sanitizer
Schema
Schema
Set
Set
StableMemoryAllocation
Stable-memory allocation descriptor.
StableMemoryAllocationMetadata
Diagnostic schema metadata associated with a stable-memory allocation.
Store
Store
StoreStableMemoryConfig
Stable-memory IDs for the three durable roles owned by one store.
Tuple
Tuple
Type
Type
TypeSanitizer
TypeSanitizer
TypeValidator
TypeValidator
Validator
Validator
Value
Value

Enums

Arg
Arg
ArgNumber
ArgNumber
FieldGeneration
Field
FieldWriteManagement
IndexExpression
IndexExpression
IndexKeyItem
IndexKeyItem
IndexKeyItemsRef
IndexKeyItemsRef
ItemTarget
ItemTarget
NodeError
NodeError
PrimaryKeySource
PrimaryKeySource
SchemaNode
SchemaNode
StoreMemoryRole
StoreStorage
Storage configuration owned by one schema store declaration.

Constants

APP_MEMORY_ID_MAX
APP_MEMORY_ID_MIN

Functions

app_memory_id_is_valid
memory_id_is_in_range
memory_id_is_reserved
stable_key_segment_is_canonical
stable_memory_key