Module node

Module node 

Schema node graph for validated canister/entity/type definitions.

This module owns the typed node descriptors used by schema validation, derive code generation, and visitor traversal.

Structs

Args
Args
Canister
Def
Entity
Entity
Enum
Enum
EnumVariant
EnumVariant
Field
FieldList
FieldList
Index
Index
Item
Item
List
List
Map
Map
Newtype
Newtype
PrimaryKey
PrimaryKey
Record
Record
Sanitizer
Sanitizer
Schema
Schema
Set
Set
Store
Store
Tuple
Tuple
Type
Type
TypeSanitizer
TypeSanitizer
TypeValidator
TypeValidator
Validator
Validator
Value
Value

Enums

Arg
Arg
ArgNumber
ArgNumber
FieldGeneration
Field
FieldWriteManagement
IndexExpression
IndexExpression
IndexKeyItem
IndexKeyItem
IndexKeyItemsRef
IndexKeyItemsRef
ItemTarget
ItemTarget
NodeError
NodeError
PrimaryKeySource
PrimaryKeySource
SchemaNode
SchemaNode

Traits

MacroNode
NODE TRAITS
TypeNode
TypeNode
ValidateNode
ValidateNode
VisitableNode
VisitableNode