pub struct StableMemoryAllocationMetadata { /* private fields */ }Expand description
Diagnostic schema metadata associated with a stable-memory allocation.
This metadata does not participate in durable allocation identity. The
durable identity remains memory_id + stable_key.
Implementations
Sourceimpl StableMemoryAllocationMetadata
impl StableMemoryAllocationMetadata
Sourcepub const fn from_accepted_schema_contract(
schema_version: u32,
schema_fingerprint: String,
) -> Self
pub const fn from_accepted_schema_contract( schema_version: u32, schema_fingerprint: String, ) -> Self
Build allocation metadata from an accepted schema/catalog authority.
Sourcepub const fn absent() -> Self
pub const fn absent() -> Self
Build absent allocation metadata for allocations with no accepted schema/catalog authority.
Sourcepub const fn schema_version(&self) -> Option<u32>
pub const fn schema_version(&self) -> Option<u32>
Accepted schema/catalog version, when known.
Sourcepub const fn schema_fingerprint(&self) -> Option<&str>
pub const fn schema_fingerprint(&self) -> Option<&str>
Accepted schema/catalog fingerprint, when known.