pub struct StoreJournaledMemoryConfig { /* private fields */ }Expand description
Stable-memory IDs for the four durable roles owned by one journaled cached-stable store.
Implementations
Sourceimpl StoreJournaledMemoryConfig
impl StoreJournaledMemoryConfig
Sourcepub const fn new(
data_memory_id: u8,
index_memory_id: u8,
schema_memory_id: u8,
journal_memory_id: u8,
) -> Self
pub const fn new( data_memory_id: u8, index_memory_id: u8, schema_memory_id: u8, journal_memory_id: u8, ) -> Self
Build a journaled memory configuration from canonical data, index, schema, and journal-tail memory IDs.
Sourcepub const fn data_memory_id(self) -> u8
pub const fn data_memory_id(self) -> u8
Canonical data-store stable memory ID.
Sourcepub const fn index_memory_id(self) -> u8
pub const fn index_memory_id(self) -> u8
Canonical index-store stable memory ID.
Sourcepub const fn schema_memory_id(self) -> u8
pub const fn schema_memory_id(self) -> u8
Canonical schema-store stable memory ID.
Sourcepub const fn journal_memory_id(self) -> u8
pub const fn journal_memory_id(self) -> u8
Durable journal-tail stable memory ID.